package color
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Module Color.OklchSource
The polar version of Oklab. See mozilla's page on it for more info. Arguably the easiest space to work with, as it closely match our perception of colors.
- lightness is a float between 0.0 and 1.0
- c is chroma, minimum is 0.0 and practical maximum value is ~0.5
- h is hue in degrees, a float value between 0.0 and 360.0
- alpha is the transparency, between 0.0 (full transparency) and 1.0 (full opacity, default)